package com.bonus.canteen.core.kitchen.service;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceUsage;
import com.bonus.canteen.core.kitchen.dto.KitchenDeviceListDTO;
import com.bonus.canteen.core.kitchen.dto.KitchenDeviceUsageListDTO;
import com.bonus.canteen.core.kitchen.vo.KitchenDeviceUsageListVO;

/**
 * 厨房设备使用记录Service接口
 *
 * @author xsheng
 * @date 2025-06-16
 */
public interface IKitchenDeviceUsageService {
    /**
     * 查询厨房设备使用记录
     *
     * @param usageId 厨房设备使用记录主键
     * @return 厨房设备使用记录
     */
    public KitchenDeviceUsageListVO selectKitchenDeviceUsageByUsageId(Long usageId);

    /**
     * 查询厨房设备使用记录列表
     *
     * @param kitchenDeviceUsage 厨房设备使用记录
     * @return 厨房设备使用记录集合
     */
    public List<KitchenDeviceUsageListVO> selectKitchenDeviceUsageList(KitchenDeviceUsageListDTO kitchenDeviceUsage);

    /**
     * 新增厨房设备使用记录
     *
     * @param kitchenDeviceUsage 厨房设备使用记录
     * @return 结果
     */
    public int insertKitchenDeviceUsage(KitchenDeviceUsage kitchenDeviceUsage);

    /**
     * 修改厨房设备使用记录
     *
     * @param kitchenDeviceUsage 厨房设备使用记录
     * @return 结果
     */
    public int updateKitchenDeviceUsage(KitchenDeviceUsage kitchenDeviceUsage);

    /**
     * 批量删除厨房设备使用记录
     *
     * @param usageIds 需要删除的厨房设备使用记录主键集合
     * @return 结果
     */
    public int deleteKitchenDeviceUsageByUsageIds(Long[] usageIds);

    /**
     * 删除厨房设备使用记录信息
     *
     * @param usageId 厨房设备使用记录主键
     * @return 结果
     */
    public int deleteKitchenDeviceUsageByUsageId(Long usageId);
}
