package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.kitchen.dto.KitchenDeviceListDTO;
import com.bonus.canteen.core.kitchen.dto.KitchenDeviceUsageListDTO;
import com.bonus.canteen.core.kitchen.vo.KitchenDeviceUsageListVO;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceUsage;
import com.bonus.canteen.core.kitchen.service.IKitchenDeviceUsageService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房设备使用记录Controller
 *
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房设备使用记录接口")
@RestController
@RequestMapping("/kitchen_device_usage")
public class KitchenDeviceUsageController extends BaseController {
    @Autowired
    private IKitchenDeviceUsageService kitchenDeviceUsageService;

    /**
     * 查询厨房设备使用记录列表
     */
    @ApiOperation(value = "查询厨房设备使用记录列表")
    //@RequiresPermissions("kitchen:usage:list")
    @GetMapping("/list")
    public TableDataInfo list(KitchenDeviceUsageListDTO kitchenDeviceUsage) {
        startPage();
        List<KitchenDeviceUsageListVO> list = kitchenDeviceUsageService.selectKitchenDeviceUsageList(kitchenDeviceUsage);
        return getDataTable(list);
    }

    /**
     * 导出厨房设备使用记录列表
     */
    @ApiOperation(value = "导出厨房设备使用记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:usage:export")
    @SysLog(title = "厨房设备使用记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房设备使用记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenDeviceUsageListDTO kitchenDeviceUsage) {
        List<KitchenDeviceUsageListVO> list = kitchenDeviceUsageService.selectKitchenDeviceUsageList(kitchenDeviceUsage);
        ExcelUtil<KitchenDeviceUsageListVO> util = new ExcelUtil<KitchenDeviceUsageListVO>(KitchenDeviceUsageListVO.class);
        util.exportExcel(response, list, "厨房设备使用记录数据");
    }

    /**
     * 获取厨房设备使用记录详细信息
     */
    @ApiOperation(value = "获取厨房设备使用记录详细信息")
    //@RequiresPermissions("kitchen:usage:query")
    @GetMapping(value = "/{usageId}")
    public AjaxResult getInfo(@PathVariable("usageId") Long usageId) {
        return success(kitchenDeviceUsageService.selectKitchenDeviceUsageByUsageId(usageId));
    }

    /**
     * 新增厨房设备使用记录
     */
    @ApiOperation(value = "新增厨房设备使用记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:usage:add")
    @SysLog(title = "厨房设备使用记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房设备使用记录")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenDeviceUsage kitchenDeviceUsage) {
        try {
            return toAjax(kitchenDeviceUsageService.insertKitchenDeviceUsage(kitchenDeviceUsage));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房设备使用记录
     */
    @ApiOperation(value = "修改厨房设备使用记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:usage:edit")
    @SysLog(title = "厨房设备使用记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房设备使用记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenDeviceUsage kitchenDeviceUsage) {
        try {
            return toAjax(kitchenDeviceUsageService.updateKitchenDeviceUsage(kitchenDeviceUsage));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房设备使用记录
     */
    @ApiOperation(value = "删除厨房设备使用记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:usage:remove")
    @SysLog(title = "厨房设备使用记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房设备使用记录")
	@PostMapping("/del/{usageIds}")
    public AjaxResult remove(@PathVariable Long[] usageIds) {
        return toAjax(kitchenDeviceUsageService.deleteKitchenDeviceUsageByUsageIds(usageIds));
    }
}
